@@ -17,15 +17,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-actions-bookmark.c,v 1.25 2004/08/28 04:04:19 ikezoe Exp $
+ *  $Id: kz-actions-bookmark.c,v 1.27 2004/10/15 13:05:02 ikezoe Exp $
  */
 
 #include "kz-actions-bookmark.h"
+#include <glib/gi18n.h>
 
-#include "gtk24backports.h"
-#include "intl.h"
 #include "kz-icons.h"
 #include "kz-bookmark-edit-win.h"
+#include "kz-smart-bookmark.h"
 
 static GtkActionEntry kz_actions_bookmark[];
 static const gint     kz_actions_bookmark_len;
@@ -158,9 +158,9 @@ act_insert_smart_bookmark (GtkAction *action, KzBookmarkEditor *editor)
 	g_return_if_fail(GTK_IS_ACTION(action));
 	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
 
-	smart = kz_bookmark_new_with_attrs(_("New Smart bookmark"), 
-					   NULL, NULL);
-	kz_bookmark_append_smart_property(smart,
+	smart = kz_smart_bookmark_new();
+	kz_bookmark_set_title(KZ_BOOKMARK(smart), _("New Smart bookmark"));
+	kz_smart_bookmark_append_property(KZ_SMART_BOOKMARK(smart),
 					  "(.*)", "%s",
 					  NULL, FALSE);
 	insert_bookmark_item(editor, smart);
