@@ -18,13 +18,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-edit.c,v 1.24 2004/08/13 07:23:44 ikezoe Exp $
+ *  $Id: kz-bookmark-edit.c,v 1.26 2004/10/15 13:05:02 ikezoe Exp $
  */
 
+#include <glib/gi18n.h>
 #include "kz-bookmark-edit.h"
+#include "kz-smart-bookmark.h"
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
 #include "kz-thumbnail.h"
 
 #define REGEX_ENTRY_WIDTH 100
@@ -110,6 +111,11 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 	GtkWidget *interval_label, *interval_spin;
 	GtkWidget *memo_label, *textview;
 	GtkWidget *thumbnail;
+#if 0
+	GtkWidget *xmlrpc, *xmlrpc_user, *xmlrpc_pass;
+	GtkWidget *check, *frame, *vbox;
+	GtkWidget *label, *entry;
+#endif
 	GtkTextBuffer *textbuf;
 
 	edit->smart = g_new0(KzSmartBookmarkEdit, 1);
@@ -201,7 +207,81 @@ kz_bookmark_edit_init (KzBookmarkEdit *edit)
 	g_signal_connect(G_OBJECT(interval_spin), "value-changed",
 			 G_CALLBACK(cb_interval_value_changed), edit);
 	gtk_widget_show(interval_spin);
+#if 0
+	/* XML-RPC interface for shared bookmark */
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), hbox,
+			 0, 1, 4, 5,  /* xpos, ypos */
+			 GTK_FILL, 0,
+			 2, 2);       /* padding x, y  */
+	gtk_widget_show(hbox);
 
+	label = gtk_label_new(_("Shared bookmark"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show(label);
+
+	/* Interface address */
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), hbox,
+			 0, 1, 4, 5,  /* xpos, ypos */
+			 GTK_FILL, 0,
+			 2, 2);       /* padding x, y  */
+	gtk_widget_show(hbox);
+
+	label = gtk_label_new(_("Interface:"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show(label);
+
+	entry = gtk_entry_new();
+	gtk_table_attach(GTK_TABLE(table), entry,
+			 1, 2, 4, 5,  /* xpos, ypos */
+			 GTK_FILL | GTK_EXPAND, 0,
+			 2, 2);       /* padding x, y  */
+	g_signal_connect(G_OBJECT(entry), "changed",
+			 G_CALLBACK(cb_location_entry_changed), edit);
+	gtk_widget_show(entry);
+	
+	/* User name */
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), hbox,
+			 0, 1, 5, 6,  /* xpos, ypos */
+			 GTK_FILL, 0,
+			 2, 2);       /* padding x, y  */
+	gtk_widget_show(hbox);
+
+	label = gtk_label_new(_("User name:"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show(label);
+
+	entry = gtk_entry_new();
+	gtk_table_attach(GTK_TABLE(table), entry,
+			 1, 2, 5, 6,  /* xpos, ypos */
+			 GTK_FILL | GTK_EXPAND, 0,
+			 2, 2);       /* padding x, y  */
+	g_signal_connect(G_OBJECT(entry), "changed",
+			 G_CALLBACK(cb_location_entry_changed), edit);
+	gtk_widget_show(entry);
+	/* Password */
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), hbox,
+			 0, 1, 6, 7,  /* xpos, ypos */
+			 GTK_FILL, 0,
+			 2, 2);       /* padding x, y  */
+	gtk_widget_show(hbox);
+
+	label = gtk_label_new(_("Password:"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show(label);
+
+	entry = gtk_entry_new();
+	gtk_table_attach(GTK_TABLE(table), entry,
+			 1, 2, 6, 7,  /* xpos, ypos */
+			 GTK_FILL | GTK_EXPAND, 0,
+			 2, 2);       /* padding x, y  */
+	g_signal_connect(G_OBJECT(entry), "changed",
+			 G_CALLBACK(cb_location_entry_changed), edit);
+	gtk_widget_show(entry);
+#endif
 	/* Memo */
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox,
@@ -435,7 +515,7 @@ kz_bookmark_edit_set_sensitive (KzBookmarkEdit *edit)
 		gtk_widget_show(edit->memo_scrwin);
 
 		if (edit->bookmark &&
-		    kz_bookmark_is_smart(edit->bookmark))
+		    KZ_IS_SMART_BOOKMARK(edit->bookmark))
 		{
 			gtk_widget_hide(edit->memo_label);
 			gtk_widget_hide(edit->memo_scrwin);
@@ -504,10 +584,10 @@ kz_bookmark_edit_sync_properties (KzBookmarkEdit *edit, KzBookmark *bookmark)
 	}
 
 	/* for smart bookmark */
-	if (kz_bookmark_is_smart(bookmark))
+	if (KZ_IS_SMART_BOOKMARK(bookmark))
 	{
 		const GList *smart_list;
-		smart_list = kz_bookmark_get_smart_list(bookmark);
+		smart_list = kz_smart_bookmark_get_smart_list(KZ_SMART_BOOKMARK(bookmark));
 		kz_bookmark_edit_set_smart_list(edit, smart_list);
 	}
 
@@ -530,7 +610,7 @@ kz_bookmark_edit_set_smart_list  (KzBookmarkEdit *edit,
 	for (node = smart_list; node; node = g_list_next(node))
 	{
 		GtkTreeIter iter;
-		KzBookmarkSmartProperty *prop;
+		KzSmartBookmarkProperty *prop;
 		
 		prop = node->data;
 		gtk_list_store_append(store, &iter);
@@ -559,7 +639,7 @@ kz_bookmark_edit_update_smart_list(KzBookmarkEdit *edit)
 	{
 		gchar *regex = NULL, *uri = NULL, *encode = NULL;
 		gboolean urlencode = FALSE;
-		KzBookmarkSmartProperty *prop;
+		KzSmartBookmarkProperty *prop;
 
 		gtk_tree_model_get(model, &iter,
 				   COLUMN_REGEX,     &regex,
@@ -568,7 +648,7 @@ kz_bookmark_edit_update_smart_list(KzBookmarkEdit *edit)
 				   COLUMN_URLENCODE, &urlencode,
 				   COLUMN_TERMINATOR);
 
-		prop = g_new0(KzBookmarkSmartProperty, 1);
+		prop = g_new0(KzSmartBookmarkProperty, 1);
 
 		if (regex)
 		{
@@ -590,7 +670,7 @@ kz_bookmark_edit_update_smart_list(KzBookmarkEdit *edit)
 		list = g_list_append(list, prop);
 	}
 
-	kz_bookmark_set_smart_list(edit->bookmark, list);
+	kz_smart_bookmark_set_smart_list(KZ_SMART_BOOKMARK(edit->bookmark), list);
 }
 
 static void
@@ -611,7 +691,7 @@ cb_smart_up_button (GtkButton *button, KzBookmarkEdit *edit)
 	if (!gtk_tree_path_prev(treepath)) goto ERROR;
 	gtk_tree_model_get_iter(model, &prev, treepath);
 
-	gtkutil_list_store_swap(store, &iter, &prev);
+	gtk_list_store_swap(store, &iter, &prev);
 	kz_bookmark_edit_update_smart_list(edit);
 	
 	gtk_tree_selection_select_path(selection, treepath);
@@ -636,7 +716,7 @@ cb_smart_down_button (GtkButton *button, KzBookmarkEdit *edit)
 	next = iter;
 	if (!gtk_tree_model_iter_next(model, &next)) return;
 
-	gtkutil_list_store_swap(store, &iter, &next);
+	gtk_list_store_swap(store, &iter, &next);
 	kz_bookmark_edit_update_smart_list(edit);
 	gtk_tree_selection_select_iter(selection, &next);
 }
