@@ -17,17 +17,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.c,v 1.36 2004/07/23 03:20:55 ikezoe Exp $
+ *  $Id: kz-bookmark-editor.c,v 1.37 2004/09/30 00:06:06 ikezoe Exp $
  */
 
 #include "kz-bookmark-editor.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
 
 #include "kazehakase.h"
 #include "gobject-utils.h"
-#include "intl.h"
-#include "gtk24backports.h"
 #include "kz-window.h"
 #include "kz-bookmark-edit.h"
 #include "kz-actions-bookmark.h"
