@@ -18,16 +18,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.55 2004/09/24 13:58:48 ikezoe Exp $
+ *  $Id: kz-bookmark.c,v 1.69 2004/10/27 09:37:09 ikezoe Exp $
  */
 
 #include "kz-bookmark.h"
 
 #include <string.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
 #include "glib-utils.h"
-#include "intl.h"
 #include "kz-marshalers.h"
 #include "utils.h"
 #include "eggregex.h"
@@ -59,6 +59,7 @@ enum {
 	PROP_TYPE,
 	PROP_TITLE,
 	PROP_DOC_TITLE,
+	PROP_ID,
 	PROP_LINK,
 	PROP_BOOKMARK_LOCATION,
 	PROP_FILE_TYPE,
@@ -68,6 +69,11 @@ enum {
 	PROP_ADDED_TIME,
 	PROP_INTERVAL,
 	PROP_SMART_LIST,
+	PROP_XMLRPC,
+	PROP_XMLRPC_USER,
+	PROP_XMLRPC_PASS,
+	PROP_CURRENT_POS,
+	PROP_LOCK,
 	PROP_EDITABLE
 };
 
@@ -110,8 +116,6 @@ static void     cb_io_load_complete           (KzIO *io,
 					       KzBookmark   *bookmark);
 static gboolean idle_load_complete            (gpointer data);
 
-static void     free_smart_list               (GList *list);
-
 static KzBookmarkFileType *
             kz_bookmark_detect_file_type  (KzBookmark   *bookmark,
 					   gchar        *buf);
@@ -120,6 +124,7 @@ static gint kz_bookmark_signals[LAST_SIGNAL] = {0};
 
 static GList *file_types = NULL;
 
+static GQuark id_quark                = 0;
 static GQuark title_quark             = 0;
 static GQuark doc_title_quark         = 0;
 static GQuark link_quark              = 0;
@@ -129,10 +134,14 @@ static GQuark description_quark       = 0;
 static GQuark last_mod_quark          = 0;
 static GQuark last_visited_quark      = 0;
 static GQuark added_time_quark        = 0;
-static GQuark smart_list_quark        = 0;
 static GQuark parent_quark            = 0;
 static GQuark children_quark          = 0;
 static GQuark interval_quark          = 0;
+static GQuark xmlrpc_quark            = 0;
+static GQuark xmlrpc_user_quark       = 0;
+static GQuark xmlrpc_pass_quark       = 0;
+static GQuark current_pos_quark       = 0;
+static GQuark lock_quark              = 0;
 static GQuark timer_quark             = 0;
 static GQuark state_quark             = 0;
 static GQuark io_quark                = 0;
@@ -204,6 +213,16 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 			KZ_BOOKMARK_NORMAL,
 			G_PARAM_READWRITE));
 
+	g_object_class_install_property(
+		object_class,
+		 PROP_ID,
+		 g_param_spec_string(
+			 "id",
+			 _("ID"),
+			 _("The ID of the bookmark"),
+			 NULL,
+			 G_PARAM_READWRITE));
+
 	g_object_class_install_property(
 		object_class,
 		 PROP_TITLE,
@@ -321,14 +340,55 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 			 _("Whether attributes of the bookmark is writable or not"),
 			 TRUE,
 			 G_PARAM_READWRITE));
+	
+	g_object_class_install_property(
+		object_class,
+		 PROP_XMLRPC,
+		 g_param_spec_string(
+			 "xmlrpc",
+			 _("XMLRPC"),
+			 _("The interface address of the XML-RPC for shared bookmark"),
+			 NULL,
+			 G_PARAM_READWRITE));
+	g_object_class_install_property(
+		object_class,
+		 PROP_XMLRPC_USER,
+		 g_param_spec_string(
+			 "xmlrpc-user",
+			 _("XMLRPC User"),
+			 _("The user name for XMLRPC"),
+			 NULL,
+			 G_PARAM_READWRITE));
+	g_object_class_install_property(
+		object_class,
+		 PROP_XMLRPC_PASS,
+		 g_param_spec_string(
+			 "xmlrpc-pass",
+			 _("XMLRPC Password"),
+			 _("The password for XMLRPC"),
+			 NULL,
+			 G_PARAM_READWRITE));
 
 	g_object_class_install_property(
 		object_class,
-		 PROP_SMART_LIST,
-		 g_param_spec_pointer(
-			 "smart-list",
-			 _("Smart List"),
-			 _("The List for the Smart Bookmark"),
+		 PROP_CURRENT_POS,
+		 g_param_spec_uint(
+			 "current",
+			 _("Current Position"),
+			 _("Current position in history"),
+			 0,
+			 G_MAXUINT,
+			 0,
+			 G_PARAM_READWRITE));
+
+	g_object_class_install_property(
+		object_class,
+		 PROP_LOCK,
+		 g_param_spec_boolean(
+			 "lock",
+			 _("Lock state"),
+			 _("Lock state for tab"),
+			 FALSE,
 			 G_PARAM_READWRITE));
 
 	kz_bookmark_signals[INSERT_CHILD_SIGNAL]
@@ -431,6 +491,7 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 	 *   * ......
 	 */
 
+	id_quark          = g_quark_from_string("KzBookmark::ID");
 	title_quark       = g_quark_from_string("KzBookmark::Title");
 	doc_title_quark   = g_quark_from_string("KzBookmark::DocumentTitle");
 	link_quark        = g_quark_from_string("KzBookmark::Link");
@@ -447,7 +508,11 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 	state_quark       = g_quark_from_string("KzBookmark::State");
 	io_quark          = g_quark_from_string("KzBookmark::KzIO");
 	io_signal_id_quark= g_quark_from_string("KzBookmark::KzIOSignalID");
-	smart_list_quark  = g_quark_from_string("KzBookmark::SmartBookmarkList");
+	xmlrpc_quark      = g_quark_from_string("KzBookmark::XMLRPC");
+	xmlrpc_user_quark = g_quark_from_string("KzBookmark::XMLRPCUser");
+	xmlrpc_pass_quark = g_quark_from_string("KzBookmark::XMLRPCPassword");
+	current_pos_quark = g_quark_from_string("KzBookmark::Current");
+	lock_quark        = g_quark_from_string("KzBookmark::Lock");
 }
 
 
@@ -465,8 +530,7 @@ kz_bookmark_dispose (GObject *object)
 	KzBookmark *bookmark;
 	guint timer_id, io_id;
 	KzIO *io;
-	GList *smart_list;
-
+	
 	g_return_if_fail(KZ_IS_BOOKMARK(object));
 
 	bookmark = KZ_BOOKMARK(object);
@@ -485,7 +549,6 @@ kz_bookmark_dispose (GObject *object)
 	if (io)
 	{
 		kz_io_stop(io);
-
 	}
 
 	io_id = GPOINTER_TO_UINT(g_object_get_qdata(object, io_signal_id_quark));
@@ -501,12 +564,6 @@ kz_bookmark_dispose (GObject *object)
 	g_object_set_qdata(object, io_signal_id_quark,
 			   GUINT_TO_POINTER(io_id));
 
-	/* smart property */
-	
-	smart_list = g_object_get_qdata(object, smart_list_quark);
-	free_smart_list(smart_list);
-	g_object_set_qdata(object, smart_list_quark, NULL);
-	
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		G_OBJECT_CLASS (parent_class)->dispose(object);
 }
@@ -518,31 +575,6 @@ kz_bookmark_dispose (GObject *object)
 				(GDestroyNotify) g_free); \
 }
 
-
-static void
-free_smart_list (GList *list)
-{
-	GList *node;
-
-	if (!list) return;
-
-	for (node = list; node; node = g_list_next(node))
-	{
-		KzBookmarkSmartProperty *prop = node->data;
-		if (!prop) continue;
-	
-		if (prop->regex)
-			g_free(prop->regex);
-		if (prop->uri)
-			g_free(prop->uri);
-		if (prop->encode)
-			g_free(prop->encode);
-		g_free(prop);
-	}
-	g_list_free(list);
-	list = NULL;
-}
-
 static void
 kz_bookmark_set_property (GObject *object,
 			  guint prop_id,
@@ -555,6 +587,10 @@ kz_bookmark_set_property (GObject *object,
 	case PROP_TYPE:
 		bookmark->type = g_value_get_enum(value);
 		break;
+	case PROP_ID:
+		g_return_if_fail(!kz_bookmark_is_separator(bookmark));
+		CHANGE_STR(object, id_quark, g_value_dup_string(value));
+		break;
 	case PROP_TITLE:
 		g_return_if_fail(!kz_bookmark_is_separator(bookmark));
 		CHANGE_STR(object, title_quark, g_value_dup_string(value));
@@ -651,10 +687,27 @@ kz_bookmark_set_property (GObject *object,
 		else
 			bookmark->flags &= ~KZ_BOOKMARK_EDITABLE_FLAG;
 		break;
-	case PROP_SMART_LIST:
-		g_return_if_fail(kz_bookmark_is_smart(bookmark));
-		g_object_set_qdata(object, smart_list_quark, 
-				   g_value_get_pointer(value));
+	case PROP_XMLRPC:
+		g_return_if_fail(kz_bookmark_is_file(bookmark));
+		CHANGE_STR(object, xmlrpc_quark, g_value_dup_string(value));
+		break;
+	case PROP_XMLRPC_USER:
+		g_return_if_fail(kz_bookmark_is_file(bookmark));
+		CHANGE_STR(object, xmlrpc_user_quark, g_value_dup_string(value));
+		break;
+	case PROP_XMLRPC_PASS:
+		g_return_if_fail(kz_bookmark_is_file(bookmark));
+		CHANGE_STR(object, xmlrpc_pass_quark, g_value_dup_string(value));
+		break;
+	case PROP_CURRENT_POS:
+		g_return_if_fail(kz_bookmark_is_folder(bookmark));
+		g_object_set_qdata(object, current_pos_quark,
+				   GUINT_TO_POINTER(g_value_get_uint(value)));
+		break;
+	case PROP_LOCK:
+		g_return_if_fail(kz_bookmark_is_folder(bookmark));
+		g_object_set_qdata(object, lock_quark,
+				   GINT_TO_POINTER(g_value_get_boolean(value)));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -677,6 +730,10 @@ kz_bookmark_get_property (GObject *object,
 	case PROP_TYPE:
 		g_value_set_enum(value, bookmark->type);
 		break;
+	case PROP_ID:
+		str = g_object_get_qdata(object, id_quark);
+		g_value_set_string(value, str);
+		break;
 	case PROP_TITLE:
 		str = g_object_get_qdata(object, title_quark);
 		g_value_set_string(value, str);
@@ -731,9 +788,27 @@ kz_bookmark_get_property (GObject *object,
 		else
 			g_value_set_boolean(value, FALSE);
 		break;
-	case PROP_SMART_LIST:
-		g_value_set_pointer(value, 
-				    g_object_get_qdata(object, smart_list_quark));
+	case PROP_XMLRPC:
+		str = g_object_get_qdata(object, xmlrpc_quark);
+		g_value_set_string(value, str);
+		break;
+	case PROP_XMLRPC_USER:
+		str = g_object_get_qdata(object, xmlrpc_user_quark);
+		g_value_set_string(value, str);
+		break;
+	case PROP_XMLRPC_PASS:
+		str = g_object_get_qdata(object, xmlrpc_pass_quark);
+		g_value_set_string(value, str);
+		break;
+	case PROP_CURRENT_POS:
+		time = GPOINTER_TO_UINT(g_object_get_qdata(object,
+							   current_pos_quark));
+		g_value_set_uint(value, time);
+		break;
+	case PROP_LOCK:
+		time = GPOINTER_TO_INT(g_object_get_qdata(object,
+							  lock_quark));
+		g_value_set_boolean(value, time);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -849,6 +924,14 @@ kz_bookmark_file_create_new (const gchar *location,
 }
 
 
+const gchar *
+kz_bookmark_get_id (KzBookmark *bookmark)
+{
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
+	return g_object_get_qdata(G_OBJECT(bookmark), id_quark);
+}
+
+
 const gchar *
 kz_bookmark_get_title (KzBookmark *bookmark)
 {
@@ -930,6 +1013,26 @@ kz_bookmark_get_interval (KzBookmark *bookmark)
 						   interval_quark));
 }
 
+const gchar * 
+kz_bookmark_get_xmlrpc (KzBookmark *bookmark)
+{
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
+	return g_object_get_qdata(G_OBJECT(bookmark), xmlrpc_quark);
+}
+
+const gchar *
+kz_bookmark_get_xmlrpc_user (KzBookmark *bookmark)
+{
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
+	return g_object_get_qdata(G_OBJECT(bookmark), xmlrpc_user_quark);
+}
+
+const gchar *
+kz_bookmark_get_xmlrpc_pass (KzBookmark *bookmark)
+{
+	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
+	return g_object_get_qdata(G_OBJECT(bookmark), xmlrpc_pass_quark);
+}
 
 gboolean
 kz_bookmark_is_editable (KzBookmark *bookmark)
@@ -961,6 +1064,10 @@ kz_bookmark_file_is_editable (KzBookmark *bookmark_file)
 	if (!kz_bookmark_get_file_type(bookmark_file))
 		return FALSE;
 
+	if (g_str_has_prefix(kz_bookmark_get_location(bookmark_file), "http://") &&
+	    !kz_bookmark_get_xmlrpc(bookmark_file))
+		return FALSE;
+
 	type = kz_bookmark_detect_file_type(bookmark_file, NULL);
 	if (type && type->to_string)
 		return TRUE;
@@ -977,6 +1084,15 @@ kz_bookmark_is_file (KzBookmark *bookmark)
 }
 
 
+void
+kz_bookmark_set_id (KzBookmark *bookmark,
+		    const gchar *id)
+{
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
+	g_object_set(G_OBJECT(bookmark), "id", id, NULL);
+}
+
+
 void
 kz_bookmark_set_title (KzBookmark *bookmark,
 		       const gchar *title)
@@ -1055,7 +1171,6 @@ kz_bookmark_set_added_time (KzBookmark *bookmark,
 	g_object_set(G_OBJECT(bookmark), "added-time", time, NULL);
 }
 
-
 void
 kz_bookmark_set_interval (KzBookmark *bookmark, guint interval)
 {
@@ -1063,6 +1178,29 @@ kz_bookmark_set_interval (KzBookmark *bookmark, guint interval)
 	g_object_set(G_OBJECT(bookmark), "interval", interval, NULL);
 }
 
+void
+kz_bookmark_set_xmlrpc (KzBookmark *bookmark,
+		        const gchar *xmlrpc)
+{
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
+	g_object_set(G_OBJECT(bookmark), "xmlrpc", xmlrpc, NULL);
+}
+
+void
+kz_bookmark_set_xmlrpc_user (KzBookmark *bookmark,
+		             const gchar *user)
+{
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
+	g_object_set(G_OBJECT(bookmark), "xmlrpc-user", user, NULL);
+}
+
+void
+kz_bookmark_set_xmlrpc_pass (KzBookmark *bookmark,
+		             const gchar *pass)
+{
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
+	g_object_set(G_OBJECT(bookmark), "xmlrpc-pass", pass, NULL);
+}
 
 gboolean
 kz_bookmark_is_separator (KzBookmark *bookmark)
@@ -1138,171 +1276,6 @@ kz_bookmark_set_folded (KzBookmark  *bookmark, gboolean folded)
 }
 
 
-gboolean
-kz_bookmark_is_smart (KzBookmark *bookmark)
-{
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), FALSE);
-	return bookmark->flags & KZ_BOOKMARK_SMART_FLAG ? TRUE : FALSE;
-}
-
-void
-kz_bookmark_append_smart_property (KzBookmark *bookmark,
-				   const gchar *regex,
-				   const gchar *uri,
-				   const gchar *encode,
-				   gboolean urlencode)
-{
-	GList *smart_list;
-	KzBookmarkSmartProperty *prop;
-
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
-
-	bookmark->flags |= KZ_BOOKMARK_SMART_FLAG;
-
-	prop = g_new0(KzBookmarkSmartProperty, 1);
-	if (regex)
-		prop->regex = g_strdup(regex);
-	if (uri)
-		prop->uri   = g_strdup(uri);
-	if (encode)
-		prop->encode = g_strdup(encode);
-	prop->urlencode = urlencode;
-
-	smart_list = g_object_get_qdata(G_OBJECT(bookmark),
-					smart_list_quark);
-	smart_list = g_list_append(smart_list, prop);
-
-	g_object_set(G_OBJECT(bookmark), "smart-list", smart_list, NULL);
-}
-
-void
-kz_bookmark_remove_smart_property (KzBookmark *bookmark)
-{
-}
-
-#define MAX_GROUPSTRING 9
-gchar *
-kz_bookmark_get_smart_uri (KzBookmark *bookmark, const gchar *text)
-{
-	gchar *smart_uri;
-	GList *smart_list, *node;
-	KzBookmarkSmartProperty *match = NULL;
-	gint n_match = 0;
-	EggRegex *egg_regex;
-	GError *error = NULL;
-
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
-
-	if (!text) 
-		return g_strdup("");
-
-	if (!(bookmark->flags & KZ_BOOKMARK_SMART_FLAG))
-	{
-		const gchar *link;
-		link = kz_bookmark_get_link(bookmark);
-		if (link)
-			return g_strdup(link);
-		else 
-			return g_strdup(text);
-	}
-
-	smart_list = g_object_get_qdata(G_OBJECT(bookmark),
-					smart_list_quark);
-
-	for (node = smart_list; node; node = g_list_next(node))
-	{
-		gchar *regex;
-		KzBookmarkSmartProperty *prop;
-		
-		prop = node->data;	
-		regex = prop->regex;
-
-		egg_regex = egg_regex_new(regex, 0, 0, &error);
-
-		if (error)
-		{
-			g_warning("KzBookmark: Regular Expression Error");
-			g_error_free(error);
-			return g_strdup(text);
-		}
-
-		n_match = egg_regex_match(egg_regex, text, -1, 0);
-
-		if (n_match > 0)		
-		{
-			match = prop;
-			break;
-		}
-		egg_regex_free(egg_regex);
-	}
-
-	if(match)
-	{
-		gboolean urlencode = match->urlencode;
-		gchar *uri = match->uri;
-		gchar *encode = match->encode;
-		gchar **strings = NULL;
-		gchar *url_strings[MAX_GROUPSTRING];
-		guint i, n = 0;
-		GString *str;
-
-		strings = egg_regex_fetch_all(egg_regex, text);
-	
-		if (strings)
-		{
-			while (strings[n] && n < MAX_GROUPSTRING)
-			{
-				url_strings[n] = ensure_encode_string(strings[n], 
-						     encode,
-						     urlencode);
-				n++;
-			}
-		}
-		g_strfreev(strings);	
-
-		/* %s is placed whole of the text */
-		str = g_string_new_len(uri, strlen(uri));
-		if (strstr(uri, "%s"))
-		{
-			gchar *url;
-			url = ensure_encode_string(text, encode,
-						   urlencode);
-			g_string_printf(str, uri, url);
-			g_free(url);
-		}
-
-		/* \1, \2 ... is replaced matching sub pattern */
-		for (i = 0; i < n; i++)
-		{
-			gchar *pos;
-			gchar *index;
-			index = g_strdup_printf("\\%d", i);
-			pos = strstr(str->str, index); 
-			while (pos)
-			{
-				gssize p = pos - str->str;
-				str = g_string_erase(str, p, strlen(index));
-				str = g_string_insert(str, p, url_strings[i]); 
-				pos = strstr(str->str, index);
-			}
-			g_free(index);
-		}
-
-		smart_uri = g_strndup(str->str, str->len);	
-		g_string_free(str, TRUE);
-
-		egg_regex_free(egg_regex);
-	}
-	else
-	{
-                /* match nothing so nothing to do... */
-		smart_uri = g_strdup(text);
-	}
-
-	return smart_uri;
-}
-
-
 static void
 kz_bookmark_real_insert_child (KzBookmark *bookmark,
 			       KzBookmark *child,
@@ -1509,6 +1482,42 @@ kz_bookmark_prev (KzBookmark  *bookmark)
 	return NULL;
 }
 
+/* return current activate tab position */
+guint
+kz_bookmark_get_current (KzBookmark *bookmark)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return 0;
+
+	return GPOINTER_TO_UINT(g_object_get_qdata(G_OBJECT(bookmark),
+						   current_pos_quark));
+}
+void
+kz_bookmark_set_current (KzBookmark  *bookmark,
+			 guint pos)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return;
+
+	g_object_set(G_OBJECT(bookmark), "current", pos, NULL);
+}
+
+gboolean
+kz_bookmark_get_lock (KzBookmark  *bookmark)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return FALSE;
+
+	return GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(bookmark),
+						  lock_quark));
+}
+
+void
+kz_bookmark_set_lock (KzBookmark  *bookmark,
+		      gboolean lock)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return;
+	
+	g_object_set(G_OBJECT(bookmark), "lock", lock, NULL);
+}
+
 
 static gint 
 compare_func (gconstpointer a, gconstpointer b)
@@ -1622,11 +1631,35 @@ kz_bookmark_save_stop (KzBookmark *bookmark)
 	g_warning("kz_bookmark_save_stop() is not implemented yet.");
 }
 
-
+#warning! FIXME! this is available only for local bookmark.
 void
 kz_bookmark_load (KzBookmark *bookmark)
 {
-	g_warning("kz_bookmark_load() is not implemented yet.");
+	const gchar *file;
+	gchar *str = NULL;
+	gsize length;
+
+	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
+
+	file = kz_bookmark_get_location(bookmark);
+
+	if (file && *file)
+	{
+		if (g_file_get_contents(file, &str, &length, NULL))
+		{
+			KzBookmarkFileType *type;
+			type = kz_bookmark_detect_file_type(bookmark, str);
+			if (!type)
+				/* use default? */;
+			if (type && type->from_string)
+			{
+				if (!kz_bookmark_get_file_type(bookmark))
+					kz_bookmark_set_file_type(bookmark, type->file_type);
+				type->from_string(bookmark, str, length, NULL);
+			}
+			g_free(str);
+		}
+	}
 }
 
 
@@ -1682,8 +1715,7 @@ cb_io_load_complete(KzIO *io, GError *error, KzBookmark *bookmark)
 	buf  = kz_io_get_buffer(io);
 	size = kz_io_get_loaded_size(io);
 
-	g_return_if_fail(buf != NULL);
-	if (size == 0) goto ERROR;
+	if (!buf || size == 0) goto ERROR;
 
 	type = kz_bookmark_detect_file_type(bookmark, (gchar *)buf);
 	if (!type)
@@ -1696,7 +1728,6 @@ cb_io_load_complete(KzIO *io, GError *error, KzBookmark *bookmark)
 	}
 
 ERROR:
-
 	g_signal_handlers_disconnect_by_func
 		(G_OBJECT(io),
 		 G_CALLBACK(cb_io_load_complete),
@@ -1786,38 +1817,6 @@ kz_bookmark_get_state (KzBookmark *bookmark)
 						  state_quark));
 }
 
-
-void
-kz_bookmark_set_smart_list (KzBookmark *bookmark, GList *list)
-{
-	GList *old_list;
-	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
-	
-	if (!kz_bookmark_is_smart(bookmark)) return;
-	
-	old_list = g_object_get_qdata(G_OBJECT(bookmark),
-				      smart_list_quark);
-	free_smart_list(old_list);
-
-	g_object_set(G_OBJECT(bookmark), "smart-list", list, NULL);
-}
-
-
-const GList *
-kz_bookmark_get_smart_list (KzBookmark *bookmark)
-{
-	const GList *list;
-
-	g_return_val_if_fail(KZ_IS_BOOKMARK(bookmark), NULL);
-	
-	if (!kz_bookmark_is_smart(bookmark)) return NULL;
-
-	list = g_object_get_qdata(G_OBJECT(bookmark),
-				  smart_list_quark);
-
-	return list;
-}
-
 static gboolean
 kz_bookmark_is_loading_all_children (KzBookmark *bookmark)
 {
@@ -1839,9 +1838,12 @@ kz_bookmark_is_loading_all_children (KzBookmark *bookmark)
 			if (ret) break;
 		}
 		next = g_list_next(node);
-		state = kz_bookmark_get_state(child);
-		ret = (state == KZ_BOOKMARK_STATE_LOADING) ? TRUE : FALSE;
-		if (ret) break;
+		if (kz_bookmark_is_file(child))
+		{
+			state = kz_bookmark_get_state(child);
+			ret = (state == KZ_BOOKMARK_STATE_LOADING) ? TRUE : FALSE;
+			if (ret) break;
+		}
 		node = next;
 	}
 
@@ -1880,6 +1882,7 @@ kz_bookmark_find_bookmark_from_uri (KzBookmark *folder, const gchar *key_uri)
 			}
 		}
 	}
+	g_list_free(children);
 
 	return bookmark;
 }
