@@ -17,13 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-view.c,v 1.16 2004/08/31 18:04:57 ikezoe Exp $
+ *  $Id: kz-bookmarks-view.c,v 1.18 2004/10/15 13:05:02 ikezoe Exp $
  */
 
 #include "kz-bookmarks-view.h"
+#include <glib/gi18n.h>
 
-#include "intl.h"
 #include "gobject-utils.h"
+#include "kz-smart-bookmark.h"
 #include "kz-favicon.h"
 
 
@@ -538,7 +539,7 @@ insert_bookmark(KzBookmarksView *view,
 						 NULL);
 		g_object_unref(G_OBJECT(image));
 	}
-	else if (kz_bookmark_is_smart(bookmark))
+	else if (KZ_IS_SMART_BOOKMARK(bookmark))
 	{
 		GtkWidget *image;
 
