@@ -18,14 +18,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-history.c,v 1.28 2004/08/13 12:34:40 ikezoe Exp $
+ *  $Id: kz-history.c,v 1.30 2004/10/17 07:25:18 makeinu Exp $
  */
 
 #include "kz-history.h"
 
-#include "intl.h"
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
-#include "kz-mozembed.h"
 
 static void kz_history_class_init (KzHistoryClass *klass);
 static void kz_history_init       (KzHistory      *history);
