@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-history.h,v 1.4 2004/06/08 11:58:57 ikezoe Exp $
+ *  $Id: kz-history.h,v 1.5 2004/08/10 13:41:22 ikezoe Exp $
  */
 
 #ifndef __KZ_HISTORY_H__
@@ -54,11 +54,6 @@ struct _KzHistoryClass
 GType		kz_history_get_type		(void);
 KzHistory      *kz_history_new			(const gchar *file);
 
-void            kz_history_connect_to_embed     (KzHistory *history,
-						 gpointer *embed);
-void            kz_history_disconnect_to_embed  (KzHistory *history,
-						 gpointer *embed);
-
 G_END_DECLS
 
 #endif /* __KZ_HISTORY_H__ */
