@@ -17,13 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.c,v 1.8 2004/09/18 04:36:57 ikezoe Exp $
+ *  $Id: kz-root-bookmark.c,v 1.10 2004/10/14 17:49:20 ikezoe Exp $
  */
 
 #include "kz-root-bookmark.h"
 
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
-#include "intl.h"
 
 
 static void     kz_root_bookmark_class_init  (KzRootBookmarkClass *klass);
@@ -58,20 +58,20 @@ kz_root_bookmark_class_init (KzRootBookmarkClass *klass)
 static void
 kz_root_bookmark_init (KzRootBookmark *root)
 {
-	root->menu          = kz_bookmark_file_new(NULL, NULL, NULL);
-	root->clip          = kz_bookmark_file_new(NULL, NULL, NULL);
-	root->bookmark_bars = kz_bookmark_pure_folder_new();
-	root->history       = kz_history_new(NULL);
-	root->sessions      = kz_bookmark_pure_folder_new();
-	root->windows       = kz_bookmark_pure_folder_new();
-	root->tab_groups    = kz_bookmark_pure_folder_new();
-	root->smarts        = NULL;
+	root->menu            = kz_bookmark_file_new(NULL, NULL, NULL);
+	root->clip            = kz_bookmark_file_new(NULL, NULL, NULL);
+	root->bookmark_bars   = kz_bookmark_pure_folder_new();
+	root->history         = kz_history_new(NULL);
+	root->sessions        = kz_bookmark_pure_folder_new();
+	root->current_session = kz_bookmark_file_new(NULL, NULL, NULL);
+	root->tab_groups      = kz_bookmark_pure_folder_new();
+	root->smarts          = NULL;
 
 	kz_bookmark_set_title(root->menu,                 "Bookmark Menu");
 	kz_bookmark_set_title(root->bookmark_bars,        "Bookmark Bars");
 	kz_bookmark_set_title(KZ_BOOKMARK(root->history), "History");
 	kz_bookmark_set_title(root->sessions,             "Sessions");
-	kz_bookmark_set_title(root->windows,              "Windows");
+	kz_bookmark_set_title(root->current_session,      "Current Session");
 	kz_bookmark_set_title(root->tab_groups,           "Tab Groups");
 }
 
@@ -127,10 +127,10 @@ kz_root_bookmark_dispose (GObject *object)
 		g_object_unref(G_OBJECT(root->sessions));
 		root->sessions = NULL;
 	}
-	if (root->windows)
+	if (root->current_session)
 	{
-		g_object_unref(G_OBJECT(root->windows));
-		root->windows = NULL;
+		g_object_unref(G_OBJECT(root->current_session));
+		root->current_session = NULL;
 	}
 	if (root->tab_groups)
 	{
@@ -338,6 +338,50 @@ kz_root_bookmark_add_bookmark_bar_file (KzRootBookmark *root,
 }
 
 
+void
+kz_root_bookmark_add_current_session_file (KzRootBookmark *root,
+					   const gchar *file)
+{
+	KzBookmark *current_session;
+
+	g_return_if_fail(KZ_IS_ROOT_BOOKMARK(root));
+	g_return_if_fail(file && *file);
+	g_return_if_fail(root->current_session);
+
+	/* FIXME! Check permission */
+
+	if (g_file_test(file, G_FILE_TEST_EXISTS))
+	{
+		current_session = kz_bookmark_file_new(file,
+					   _("Current Session"),
+					   "XBEL");
+	}
+	else
+	{
+		current_session = kz_bookmark_file_create_new(file,
+						  _("Current Session"),
+						  "XBEL");
+	}
+
+	if (root->current_session)
+	{
+		g_object_unref(G_OBJECT(root->current_session));
+		root->current_session = NULL;
+	}
+
+	if (current_session)
+	{
+		kz_bookmark_load(current_session);
+		root->current_session = current_session;
+		/*	
+		kz_bookmark_insert_before(KZ_BOOKMARK(root),
+					  current_session, root->bookmark_bars);
+		g_object_unref(current_session);
+		*/
+	}
+}
+
+
 void
 kz_root_bookmark_save_all (KzRootBookmark *root)
 {
