@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.h,v 1.6 2004/09/18 04:36:57 ikezoe Exp $
+ *  $Id: kz-root-bookmark.h,v 1.7 2004/10/14 17:49:20 ikezoe Exp $
  */
 
 #ifndef __KZ_ROOT_BOOKMARK_H__
@@ -52,7 +52,7 @@ struct _KzRootBookmark
 	KzBookmark *smarts;
 	/* ??? */
 	KzBookmark *sessions;
-	KzBookmark *windows;
+	KzBookmark *current_session;
 	KzBookmark *tab_groups;
 
 	KzRootBookmarkPriv *priv;
@@ -84,6 +84,9 @@ void	        kz_root_bookmark_add_smartbookmark_file
 						      (KzRootBookmark *root,
 						       const gchar    *file,
 						       const gchar    *subfile);
+void	        kz_root_bookmark_add_current_session_file
+						      (KzRootBookmark *root,
+						       const gchar    *file);
 void		kz_root_bookmark_set_history_file     (KzRootBookmark *root,
 						       const gchar    *file);
 
@@ -116,9 +119,23 @@ void		kz_root_bookmark_save_all	      (KzRootBookmark *root);
  *     |    |
  *     |    +-- ......
  *     |
- *     +-- Windows (Current session?)
- *     |    +
- *     |    +-- ......
+ *     +-- Current session
+ *     |    | 
+ *     |    +-- Window 0
+ *     |    |    |
+ *     |    |    +-- Tab 0
+ *     |    |    |
+ *     |    |    +-- Tab 1
+ *     |    |    |
+ *     |    |    +-- ......
+ *     |    |
+ *     |    +-- Window 1
+ *     |         | 
+ *     |         +-- Tab 0
+ *     |         |
+ *     |         +-- Tab 1
+ *     |         |
+ *     |         +-- ...... 
  *     |
  *     +-- Tab Groups
  *          |
