@@ -17,13 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.47 2004/09/17 01:28:26 ikezoe Exp $
+ *  $Id: kz-xbel.c,v 1.56 2004/10/15 13:05:02 ikezoe Exp $
  */
 
 #include "kazehakase.h"
 #include "kz-xbel.h"
 #include "kz-xml.h"
 #include "utils.h"
+#include "kz-smart-bookmark.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -313,118 +314,84 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 	     node;
 	     node = kz_xml_node_next(node))
 	{
+		const GList *attrs, *a_node;
+		const gchar *owner;
+		const gchar *smart_regex  = NULL;
+		const gchar *smart_uri    = NULL;
+		const gchar *smart_encode = NULL;
+		gboolean urlencode = FALSE;
+		gint interval;
+
 		if (!kz_xml_node_is_element(node)) continue;
 
-		if (kz_xml_node_name_is(node, "metadata"))
-		{
-			const GList *attrs, *a_node;
-			const gchar *owner;
-			const gchar *smart_regex  = NULL;
-			const gchar *smart_uri    = NULL;
-			const gchar *smart_encode = NULL;
-			gboolean urlencode = FALSE;
-			gint interval;
+		if (!kz_xml_node_name_is(node, "metadata")) continue;
 			
-			/* We should ignore other owners such as Galeon. */
-			owner = kz_xml_node_get_attr(node, "owner");
-			if (!owner || strcmp(owner, KAZEHAKASE_URI))
-				continue;
+		/* We should ignore other owners such as Galeon. */
+		owner = kz_xml_node_get_attr(node, "owner");
+		if (!owner || strcmp(owner, KAZEHAKASE_URI))
+			continue;
 			
-			attrs = kz_xml_node_get_attrs(node);
+		attrs = kz_xml_node_get_attrs(node);
 
-			for (a_node = attrs; a_node; a_node = g_list_next(a_node))
-			{
-				KzXMLAttr *attr = a_node->data;
-
-				if (!strncmp(attr->name, "kz:update_interval", 118))
-				{
-					interval = atoi(attr->value);
-					kz_bookmark_set_interval(bookmark, interval);
-				}
-				else if (!strncmp(attr->name, "kz:smart_regex", 14))
-				{
-					smart_regex = attr->value;
-				}
-				else if (!strncmp(attr->name, "kz:smart_uri", 12))
-				{
-					smart_uri = attr->value;
-				}
-				else if (!strncmp(attr->name, "kz:smart_encode", 15))
-				{
-					smart_encode = attr->value;
-				}
-				else if (!strncmp(attr->name, "kz:smart_urlencode", 16))
-				{
-					urlencode = TRUE;
-				}
-			}
-
-			if (smart_regex && smart_uri)
-			{
-				 kz_bookmark_append_smart_property(
-					bookmark,
-					smart_regex, smart_uri, 
-					smart_encode, urlencode);
-			}
-
-			{
-#if 1
-				/* 
-				 * for compatibility, 
-				 * we need to load "update_interval" 
-				 * from node.
-				 */
-				KzXMLNode *interval_node;
-				interval_node = xml_node_get_named_node(node, 
-							   "update_interval");
-				if (interval_node)
-				{
-					/*
-					gchar *str;
-					str = kz_xml_node_to_str(interval_node);		
-					interval = atoi(str);
-					kz_bookmark_set_interval(bookmark,
-								 interval);
-					kz_xml_node_set_attr(node,
-							     "kz:update_interval",
-							     str);
-					g_free(str);
-					*/
-					/* clean "update_interval" node */
-					KzXMLNode *next = kz_xml_node_next(interval_node);
-					kz_xml_node_remove_child(node, interval_node);
-					kz_xml_node_unref(interval_node);
-					/* space is also removed */
-					if (kz_xml_node_is_space(next))
-					{
-						kz_xml_node_remove_child(node, next);
-						kz_xml_node_unref(next);
-					}
-				}
-#endif
-			}
-			/*
-			if (kz_bookmark_get_owner(bookmark))
-			{
-				g_warning("metadata owner attribute is duplicated!");
-				continue;
-			}
-			owner = kz_xml_node_get_attr(node, "owner");
-			kz_bookmark_set_owner(folder, owner);
-			*/
-		}
-		else if (kz_xml_node_name_is(node, "location"))
+		for (a_node = attrs; a_node; a_node = g_list_next(a_node))
 		{
-			g_warning("kzXBEL: \"location\" element is obsolete");
+			KzXMLAttr *attr = a_node->data;
+
+			if (!strncmp(attr->name, "kz:update_interval", 118))
+			{
+				interval = atoi(attr->value);
+				kz_bookmark_set_interval(bookmark, interval);
+			}
+			else if (!strncmp(attr->name, "kz:smart_regex", 14))
+			{
+				smart_regex = attr->value;
+			}
+			else if (!strncmp(attr->name, "kz:smart_uri", 12))
+			{
+				smart_uri = attr->value;
+			}
+			else if (!strncmp(attr->name, "kz:smart_encode", 15))
+			{
+				smart_encode = attr->value;
+			}
+			else if (!strncmp(attr->name, "kz:smart_urlencode", 16))
+			{
+				urlencode = TRUE;
+			}
+			else if (!strncmp(attr->name, "kz:xmlrpc", 9))
+			{
+				kz_bookmark_set_xmlrpc(bookmark, attr->value);
+			}
+			else if (!strncmp(attr->name, "kz:xmlrpc_user", 14))
+			{
+				kz_bookmark_set_xmlrpc_user(bookmark, attr->value);
+			}
+			else if (!strncmp(attr->name, "kz:xmlrpc_pass", 14))
+			{
+				kz_bookmark_set_xmlrpc_pass(bookmark, attr->value);
+			}
+			else if (!strncmp(attr->name, "kz:current_position", 18))
+			{
+				gint pos = atoi(attr->value);
+				kz_bookmark_set_current(bookmark, pos);
+			}
+			else if (!strncmp(attr->name, "kz:lock", 7))
+			{
+				if (!strcmp(attr->value, "yes"))
+					kz_bookmark_set_lock(bookmark, TRUE);
+			}
 		}
-		else if (kz_xml_node_name_is(node, "update_interval"))
+
+		if (smart_regex && smart_uri)
 		{
-			g_warning("KzXBEL: \"update_interval\" element is obsolete!");
+			 kz_smart_bookmark_append_property(
+				KZ_SMART_BOOKMARK(bookmark),
+				smart_regex, smart_uri, 
+				smart_encode, urlencode);
 		}
 	}	
 }
 
-
 static KzXMLNode *
 xml_node_find_metadata_node (KzXMLNode *parent)
 {
@@ -437,24 +404,64 @@ xml_node_find_metadata_node (KzXMLNode *parent)
 	     node;
 	     node = kz_xml_node_next(node))
 	{
-		if (kz_xml_node_name_is(node, "metadata"))
-		{
-			const gchar *owner;
+		const gchar *owner;
+	
+		if (!kz_xml_node_name_is(node, "metadata"))
+			continue;
 
-			owner = kz_xml_node_get_attr(node, "owner");
-			if (owner && !strcmp(owner, KAZEHAKASE_URI))
-				return node;
-		}
+		owner = kz_xml_node_get_attr(node, "owner");
+		if (owner && !strcmp(owner, KAZEHAKASE_URI))
+			return node;
 	}
 
 	return NULL;
 }
 
 
+static gboolean
+xml_node_has_smart_property (KzXMLNode *parent)
+{
+	const GList *attrs, *list;
+	KzXMLNode *info_node, *node;
+	gboolean ret = FALSE;
+			
+	info_node = xml_node_get_named_node(parent, "info");
+	if (!info_node) return FALSE;
+	
+	for (node = kz_xml_node_first_child(info_node);
+	     node;
+	     node = kz_xml_node_next(node))
+	{
+		const gchar *owner;
+		if (!kz_xml_node_name_is(node, "metadata"))
+			continue;
+
+		owner = kz_xml_node_get_attr(node, "owner");
+		if (!owner || strcmp(owner, KAZEHAKASE_URI))
+			continue;
+
+		attrs = kz_xml_node_get_attrs(node);
+
+		for (list = attrs; list; list = g_list_next(list))
+		{
+			KzXMLAttr *attr = list->data;
+
+			if (!strncmp(attr->name, "kz:smart", 7))
+			{
+				ret = TRUE;
+				break;
+			}
+		}
+		if (ret) break;
+	}
+	return ret;
+}
+
+
 static gboolean
 xml_node_has_location (KzXMLNode *parent)
 {
-	KzXMLNode *child, *gchild;
+	KzXMLNode *child;
 
 	g_return_val_if_fail(parent, FALSE);
 
@@ -464,23 +471,6 @@ xml_node_has_location (KzXMLNode *parent)
 	child = xml_node_find_metadata_node(parent);
 	if (!child) return FALSE;
 
-#if 1
-	gchild = xml_node_get_named_node(child, "location");
-	if (gchild)
-	{	
-		KzXMLNode *next = kz_xml_node_next(gchild);
-		/* remove "location" element */
-		kz_xml_node_remove_child(child, gchild);
-		kz_xml_node_unref(gchild);
-		
-		/* space is also removed */
-		if (kz_xml_node_is_space(next))
-		{
-			kz_xml_node_remove_child(child, next);
-			kz_xml_node_unref(next);
-		}
-	}
-#endif
 	if (kz_xml_node_get_attr(child, "kz:location"))
 		return TRUE;
 	
@@ -507,21 +497,6 @@ xml_node_get_location (KzXMLNode *parent)
 	if (!attr) return NULL;
 	
 	return attr;
-#if 0
-	gchild = xml_node_get_named_node(child, "location");
-	if (!gchild) return NULL;
-
-	location = kz_xml_node_to_str(gchild);
-	/* set location into metadata attribute */
-	kz_xml_node_set_attr(child, 
-			     "kz:location", location);
-
-	/* remove "location" element */
-	kz_xml_node_remove_child(child, gchild);
-	kz_xml_node_unref(gchild);
-
-	return location;
-#endif
 }
 
 
@@ -571,6 +546,7 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 		{
 			KzBookmark *folder;
 			const gchar *folded_str;
+			const gchar *id;
 			gboolean folded;
 
 			if (xml_node_has_location(node))
@@ -591,6 +567,10 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 			folded = folded_str && !strcmp(folded_str, "yes");
 			kz_bookmark_set_folded(folder, folded);
 
+			id = kz_xml_node_get_attr(node, "id");
+			if (id)
+				kz_bookmark_set_id(folder, id);
+
 			BOOKMARK_SET_BUILDING(folder);
 			g_object_set_qdata(G_OBJECT(folder),
 					   node_quark, node);
@@ -602,10 +582,15 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 		}
 		else if (kz_xml_node_name_is(node, "bookmark"))
 		{
-			KzBookmark *child_bookmark = kz_bookmark_new();
+			KzBookmark *child_bookmark;
 			const GList *attrs = kz_xml_node_get_attrs(node);
 			const GList *list;
 
+			if (xml_node_has_smart_property(node))
+				child_bookmark = kz_smart_bookmark_new();
+			else
+				child_bookmark = kz_bookmark_new();
+
 			BOOKMARK_SET_BUILDING(bookmark);
 			g_object_set_qdata(G_OBJECT(child_bookmark),
 					   node_quark, node);
@@ -632,6 +617,10 @@ parse_child_node (KzBookmark *bookmark, KzXMLNode *parent)
 						t = atoi(attr->value);	
 					kz_bookmark_set_last_visited(child_bookmark, t);
 				}
+				else if (!strcmp(name, "id"))
+				{
+					kz_bookmark_set_id(child_bookmark, attr->value);
+				}
 			}
 
 			parse_child_node(child_bookmark, node);
@@ -749,10 +738,6 @@ xml_node_append_metadata_node (KzXMLNode *node)
 	kz_xml_node_set_attr(metadata_node, "owner", KAZEHAKASE_URI);
 	kz_xml_node_append_child(info_node, metadata_node);
 
-	/* space2 */
-	space = kz_xml_text_node_new("\n");
-	kz_xml_node_append_child(metadata_node, space);
-
 	/* space3 */
 	space = kz_xml_text_node_new("\n");
 	kz_xml_node_append_child(info_node, space);
@@ -865,7 +850,7 @@ xml_node_set_smart_list (KzXMLNode *node,
 	/* append new smart properties */
 	for (smart_node = smart_list; smart_node; smart_node = g_list_next(smart_node))
 	{
-		KzBookmarkSmartProperty *prop;
+		KzSmartBookmarkProperty *prop;
 		KzXMLNode *metadata_node, *space;
 		
 		metadata_node = kz_xml_element_node_new("metadata");
@@ -943,6 +928,9 @@ create_xml_node (KzBookmark *bookmark)
 	}
 	else if (kz_bookmark_is_folder(bookmark))
 	{
+		KzXMLNode *metanode;
+		gint pos = kz_bookmark_get_current(bookmark);
+		gboolean lock = kz_bookmark_get_lock(bookmark);
 		/*
 		 * <folder>\n
 		 * <title/>
@@ -956,13 +944,37 @@ create_xml_node (KzBookmark *bookmark)
 		kz_xml_node_append_child(node, space);
 
 		xml_node_append_title (node, bookmark);
+		
+		if (pos || lock)
+		{
+			metanode = xml_node_find_metadata_node(node);
+	
+			if (!metanode)
+				metanode = xml_node_append_metadata_node(node);
+
+			if (pos)
+			{
+				gchar *pos_str = g_strdup_printf("%d", pos);
+				kz_xml_node_set_attr(metanode, "kz:current_position", pos_str);
+			}
+			if (lock)
+			{
+				const gchar *str;
+				if (lock)
+					str = "yes";
+				else
+					str = "no";
+				kz_xml_node_set_attr(metanode, "kz:lock", str);
+			}
+		}
 	}
-	else if (kz_bookmark_is_smart(bookmark))
+	else if (KZ_IS_SMART_BOOKMARK(bookmark))
 	{
 		const GList *smart_list;
 		const gchar *uri = kz_bookmark_get_link(bookmark);
 		
-		smart_list = kz_bookmark_get_smart_list(bookmark);
+		smart_list = kz_smart_bookmark_get_smart_list(
+				KZ_SMART_BOOKMARK(bookmark));
 	
 		node = kz_xml_element_node_new("bookmark");
 		if (uri)
@@ -981,6 +993,7 @@ create_xml_node (KzBookmark *bookmark)
 	else
 	{
 		const gchar *uri = kz_bookmark_get_link(bookmark);
+		const gchar *id = kz_bookmark_get_id(bookmark);
 		guint visited = kz_bookmark_get_last_visited(bookmark);
 		guint added = kz_bookmark_get_added_time(bookmark);
 		/*
@@ -992,6 +1005,8 @@ create_xml_node (KzBookmark *bookmark)
 		node = kz_xml_element_node_new("bookmark");
 		if (uri)
 			kz_xml_node_set_attr(node, "href", uri);
+		if (id)
+			kz_xml_node_set_attr(node, "id", id);
 		if (visited != 0)
 		{
 			gchar *str = g_strdup_printf("%d", visited);
@@ -1266,7 +1281,14 @@ cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 	/*
 	 * FIXME! We should use hash table.
 	 */
-	if (!strcmp(prop, "title"))
+	if (!strcmp(prop, "id"))
+	{
+		gchar *id = g_value_dup_string(&value);
+
+		kz_xml_node_set_attr(node, "id", id);
+		g_free(id);
+	}
+	else if (!strcmp(prop, "title"))
 	{
 		gchar *title = g_value_dup_string(&value);
 
@@ -1290,12 +1312,10 @@ cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 	else if (!strcmp(prop, "location"))
 	{
 		xml_node_set_location(node, bookmark);
-		/* xml_node_set_metadata(node, "location", str) */
 	}
 	else if (!strcmp(prop, "interval"))
 	{
 		xml_node_set_interval(node, bookmark);
-		/* xml_node_set_metadata(node, "update_interval", str); */
 	}
 	else if (!strcmp(prop, "last-visited"))
 	{
@@ -1317,6 +1337,73 @@ cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 		smart_list =  g_value_get_pointer(&value);
 		xml_node_set_smart_list(node, bookmark, smart_list);
 	}
+	else if (!strcmp(prop, "xmlrpc"))
+	{
+		KzXMLNode *metanode;
+		gchar *xmlrpc = g_value_dup_string(&value);
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:xmlrpc", xmlrpc);
+		g_free(xmlrpc);
+	}
+	else if (!strcmp(prop, "xmlrpc-user"))
+	{
+		KzXMLNode *metanode;
+		gchar *xmlrpc = g_value_dup_string(&value);
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:xmlrpc_user", xmlrpc);
+		g_free(xmlrpc);
+	}
+	else if (!strcmp(prop, "xmlrpc-pass"))
+	{
+		KzXMLNode *metanode;
+		gchar *xmlrpc = g_value_dup_string(&value);
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:xmlrpc_user", xmlrpc);
+		g_free(xmlrpc);
+	}
+	else if (!strcmp(prop, "current"))
+	{
+		KzXMLNode *metanode;
+		guint pos = g_value_get_uint(&value);
+		gchar *pos_str = g_strdup_printf("%d", pos);
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:current_position", pos_str);
+		g_free(pos_str);
+	}
+	else if (!strcmp(prop, "lock"))
+	{
+		KzXMLNode *metanode;
+		const gchar *str;
+		gboolean lock = g_value_get_boolean(&value);
+		
+		if (lock)
+			str = "yes";
+		else
+			str = "no";
+
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:lock", str);
+	}
 	g_value_unset(&value);
 }
 
