@@ -18,11 +18,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "stdio.h"
+#include <stdio.h>
+#include <glib/gi18n.h>
 
 #include "gobject-utils.h"
 #include "kz-downloader.h"
-#include "intl.h"
 
 enum {
 	START_SIGNAL,
@@ -173,7 +173,6 @@ kz_downloader_dispose (GObject *object)
 	g_return_if_fail(KZ_IS_DOWNLOADER(object));
 
 	downloader = KZ_DOWNLOADER(object);
-
 	if (downloader->io)
 		g_object_unref(downloader->io);
 	if (downloader->uri)
@@ -260,6 +259,8 @@ kz_downloader_new (const gchar *uri)
 					"io",  io,
 					NULL));
 
+	g_object_unref(io);
+
 	return dl;
 }
 
@@ -279,7 +280,8 @@ kz_downloader_new_with_filename (const gchar *uri, const gchar *filename)
 					"filename", filename,
 					"io",       io,
 					NULL));
-	
+	g_object_unref(io);
+
 	return dl;
 }
 
