@@ -17,16 +17,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-sidebar.c,v 1.13 2004/08/10 04:47:15 ikezoe Exp $
+ *  $Id: kz-sidebar.c,v 1.15 2004/10/02 00:48:01 ikezoe Exp $
  */
 
 #include "kz-sidebar.h"
 
 #include <string.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "gobject-utils.h"
-#include "intl.h"
 #include "kz-bookmarks-sidebar.h"
 #include "kz-downloader-sidebar.h"
 #include "kz-tabtree.h"
@@ -69,7 +69,7 @@ static void     kz_sidebar_get_property   (GObject       *object,
 static gboolean kz_sidebar_change_content (KzSidebar *sidebar,
 					   KzSidebarEntry *entry);
 
-static void     cb_option_menu_changed    (GtkOptionMenu *option_menu,
+static void     cb_option_menu_changed    (GtkComboBox   *option_menu,
 					   KzSidebar     *sidebar);
 static void     cb_close_button           (GtkWidget     *widget,
 					   KzSidebar     *sidebar);
@@ -115,7 +115,7 @@ kz_sidebar_class_init (KzSidebarClass *klass)
 static void
 kz_sidebar_init (KzSidebar *sidebar)
 {
-	GtkWidget *hbox, *option_menu, *menu, *close_button, *image;
+	GtkWidget *hbox, *option_menu, *close_button, *image;
 	gint i;
 
 	/* top hbox */
@@ -124,23 +124,18 @@ kz_sidebar_init (KzSidebar *sidebar)
 	gtk_widget_show(GTK_WIDGET(hbox));
 
 	/* option menu */
-	option_menu = gtk_option_menu_new();
-	gtk_button_set_relief(GTK_BUTTON(option_menu), GTK_RELIEF_NONE);
+	option_menu = gtk_combo_box_new_text();
 	gtk_box_pack_start(GTK_BOX(hbox), option_menu, FALSE, FALSE, 0);
 	gtk_widget_show(GTK_WIDGET(option_menu));
 
 	sidebar->content = NULL;
 	sidebar->current_entry = NULL;
 
-	menu = gtk_menu_new();
 	for (i = 0; i < n_sidebar_entries; i++)
 	{
-		GtkWidget *item;
-		item = gtk_menu_item_new_with_label(_(sidebar_entries[i]->label));
-		gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
-		gtk_widget_show (item);
+		gtk_combo_box_append_text(GTK_COMBO_BOX(option_menu),
+					  _(sidebar_entries[i]->label));
 	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(option_menu), menu);
 	g_signal_connect (option_menu, "changed",
 			  G_CALLBACK (cb_option_menu_changed), sidebar);
 
@@ -294,7 +289,7 @@ kz_sidebar_set_current (KzSidebar *sidebar, const gchar *label)
 		g_signal_handlers_block_by_func(G_OBJECT(sidebar->option_menu),
 						G_CALLBACK(cb_option_menu_changed),
 						sidebar);
-		gtk_option_menu_set_history(GTK_OPTION_MENU(sidebar->option_menu), i);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(sidebar->option_menu), i);
 		g_signal_handlers_unblock_by_func(G_OBJECT(sidebar->option_menu),
 						  G_CALLBACK(cb_option_menu_changed),
 						  sidebar);
@@ -306,14 +301,14 @@ kz_sidebar_set_current (KzSidebar *sidebar, const gchar *label)
 }
 
 static void
-cb_option_menu_changed (GtkOptionMenu *option_menu, KzSidebar *sidebar)
+cb_option_menu_changed (GtkComboBox *option_menu, KzSidebar *sidebar)
 {
 	gint num;
 
-	g_return_if_fail (GTK_IS_OPTION_MENU(option_menu));
+	g_return_if_fail (GTK_IS_COMBO_BOX(option_menu));
 	g_return_if_fail (KZ_IS_SIDEBAR(sidebar));
 
-	num = gtk_option_menu_get_history(option_menu);
+	num = gtk_combo_box_get_active(option_menu);
 	g_return_if_fail(num >= 0 && num < n_sidebar_entries);
 
 	kz_sidebar_change_content(sidebar, sidebar_entries[num]);
