@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c,v 1.21 2004/07/28 04:58:46 ikezoe Exp $
+ *  $Id: kz-xml.c,v 1.23 2004/10/15 03:38:58 makeinu Exp $
  */
 
 #include "kz-xml.h"
@@ -67,7 +67,7 @@ kz_xml_init (KzXML *xml)
 	xml->dtd           = NULL;
 	xml->encoding      = g_strdup("UTF-8");
 	xml->root          = kz_xml_node_new(xml, KZ_XML_NODE_DOC_ROOT);
-	xml->priv          = g_new0(KzXMLPriv, 1);;
+	xml->priv          = g_new0(KzXMLPriv, 1);
 	xml->priv->context = NULL;
 }
 
@@ -278,7 +278,7 @@ kz_xml_load_xml (KzXML *xml, const gchar *buffer, guint length)
 	}
 	else
 	{
-		g_warning("Bookmark parse error!: %s", error->message);
+		g_warning("XML parse error!: %s", error->message);
 		g_error_free(error);
 	}
 	g_markup_parse_context_free (context);
