@@ -91,8 +91,6 @@
 #	include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#define SCRAP_IMAGE_DIR "scrap_images/"
-
 KzMozWrapper::KzMozWrapper () :
 	mWebBrowser (nsnull),
 	mEventReceiver (nsnull),
@@ -135,10 +133,12 @@ KzMozWrapper::Init (KzMozEmbed *kzembed)
 		if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
 	}
 */
-#if 0
+#if 1
+	mKzMozEventListener = new KzMozEventListener();
 	rv = mKzMozEventListener->Init (kzembed);
 	if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
 	GetListener();
+	AttachListeners();
 #endif
 	return NS_OK;
 }
@@ -361,9 +361,7 @@ KzMozWrapper::GetHtmlWithContents (nsISelection *selection,
 
 	HTMLSourceFromNode(domDoc, bodyNode, selection, range, storedir, string);
 
-	nsAutoString tail;
-	tail.AssignWithConversion("\n</html>");
-	string.Append(tail);
+	string.Append(NS_LITERAL_STRING("\n</html>"));
 
 	return NS_OK;
 }
@@ -788,8 +786,6 @@ KzMozWrapper::GetHistoryEntry (PRInt32 index, nsIHistoryEntry **he)
 nsresult 
 KzMozWrapper::GoHistoryIndex (gint index)
 {
-	nsresult rv;
-
 	nsCOMPtr<nsIWebNavigation> nav = do_QueryInterface (mWebBrowser);
 	if (!nav) return NS_ERROR_FAILURE;
 
@@ -978,15 +974,14 @@ KzMozWrapper::SetAttributes (nsIDOMNode *node,
 }
 
 void
-KzMozWrapper::SetStartTag (const gchar *tagname,
+KzMozWrapper::SetStartTag (const nsAString &tag,
 			   nsIDOMDocument *domDoc,
 			   nsAString &aString)
 {
 	NS_NAMED_LITERAL_STRING(lt, "<");
 	NS_NAMED_LITERAL_STRING(gt, ">");
 	NS_NAMED_LITERAL_STRING(cr, "\n");
-	nsAutoString tag;
-	tag.AssignWithConversion(tagname);
+
 	nsCOMPtr<nsIDOMNodeList> nodeList;
 	domDoc->GetElementsByTagName(tag, getter_AddRefs(nodeList));
 	
@@ -1023,9 +1018,7 @@ KzMozWrapper::SetHTMLHeadSource (nsIDOMDocument *domDocument,
 	NS_NAMED_LITERAL_STRING(lt, "<");
 	NS_NAMED_LITERAL_STRING(gt, ">");
 	NS_NAMED_LITERAL_STRING(cr, "\n");
-	
-	nsAutoString dt;
-	dt.AssignWithConversion("!DOCTYPE");
+	NS_NAMED_LITERAL_STRING(dt, "!DOCTYPE");
 	
 	nsCOMPtr<nsIDOMNode> domNode;
 	domNode = do_QueryInterface(domDocument);
@@ -1049,15 +1042,14 @@ KzMozWrapper::SetHTMLHeadSource (nsIDOMDocument *domDocument,
 	}		   
 
 	// html node <html ...>
-	SetStartTag("html", domDocument, aSource);
+	SetStartTag(NS_LITERAL_STRING("html"), domDocument, aSource);
 
-	nsAutoString h;
-	h.AssignWithConversion("head");
 	nsCOMPtr<nsIDOMNodeList> headList;
-	domDocument->GetElementsByTagName(h, getter_AddRefs(headList));
+	domDocument->GetElementsByTagName(NS_LITERAL_STRING("head"),
+					  getter_AddRefs(headList));
 	if (!headList) return;
 
-	PRUint32 index, length;
+	PRUint32 length;
 	headList->GetLength(&length);
 	if (!length) return;
 
@@ -1101,7 +1093,7 @@ KzMozWrapper::HTMLSourceFromNode(nsIDOMDocument *domDoc,
 		string += lt + tagname;
 	
 		char *relattr =  NULL;
-		GetAttributeFromNode(node, "rel", &relattr);
+		GetAttributeFromNode(node, NS_LITERAL_STRING("rel"), &relattr);
 				
 		nsCOMPtr<nsIDOMNamedNodeMap> attrs;
 		node->GetAttributes(getter_AddRefs(attrs));
@@ -1160,8 +1152,6 @@ KzMozWrapper::HTMLSourceFromNode(nsIDOMDocument *domDoc,
 				{
 					// change the encoding
 					PRInt32 find, start, end;
-					nsAutoString UTF8;
-					UTF8.AssignWithConversion("UTF-8");
 					
 					find = value.Find("charset=", PR_TRUE, 0, -1);
 					if (find != kNotFound)
@@ -1171,7 +1161,7 @@ KzMozWrapper::HTMLSourceFromNode(nsIDOMDocument *domDoc,
 						if (end == kNotFound)	
 							end = value.Length();
 						value.Cut(start, end - start);
-						value.Insert(UTF8, start);
+						value.Insert(NS_LITERAL_STRING("UTF-8"), start);
 					}
 					string += dq + value + dq;
 				}
@@ -1435,6 +1425,8 @@ KzMozWrapper::PrintPreview (void)
 	print->GetGlobalPrintSettings(getter_AddRefs(options));
 	options->SetPaperSize(nsIPrintSettings::kPaperSizeNativeData);
 	rv = print->PrintPreview(options, mDOMWindow, nsnull);
+
+	return rv;
 }
 
 // these functions were picked from Galeon-1.3.17.
@@ -1539,10 +1531,8 @@ KzMozWrapper::SetImageZoom (float aZoom)
         rv = GetMainDomDocument(getter_AddRefs(domDoc));
         if (NS_FAILED(rv) || !domDoc) return NS_ERROR_FAILURE;
 
-	nsAutoString tagname;
-	tagname.AssignWithConversion("img");
 	nsCOMPtr<nsIDOMNodeList> nodeList;
-	rv = domDoc->GetElementsByTagName(tagname,
+	rv = domDoc->GetElementsByTagName(NS_LITERAL_STRING("img"),
 					  getter_AddRefs(nodeList));
         if (NS_FAILED(rv) || !domDoc) return NS_ERROR_FAILURE;
 
@@ -1560,7 +1550,8 @@ KzMozWrapper::SetImageZoom (float aZoom)
 		PRInt32 width = 0, height = 0;
 
 		char *width_str =  NULL;
-		GetAttributeFromNode(node, "width", &width_str);
+		GetAttributeFromNode(node, NS_LITERAL_STRING("width"),
+				     &width_str);
 		if (!width_str) continue;
 
 		if (str_isdigit(width_str))
@@ -1568,7 +1559,8 @@ KzMozWrapper::SetImageZoom (float aZoom)
 		g_free(width_str);
 		
 		char *height_str =  NULL;
-		GetAttributeFromNode(node, "height", &height_str);
+		GetAttributeFromNode(node, NS_LITERAL_STRING("height"),
+				     &height_str);
 		if (!height_str) continue;
 	
 		if (str_isdigit(height_str))
@@ -1582,13 +1574,12 @@ KzMozWrapper::SetImageZoom (float aZoom)
 		height = (PRInt32)(height * aZoom);
 		nsCOMPtr<nsIDOMElement> elm;
 		elm = do_QueryInterface(node);
-		nsAutoString style, style_value;
-		style.Assign(NS_ConvertUTF8toUCS2("style"));
+		nsAutoString style_value;
 		gchar *v;
 		v = g_strdup_printf("width: %dpx; height: %dpx;",
 				    width, height);
 		style_value.Assign(NS_ConvertUTF8toUCS2(v));
-		elm->SetAttribute(style, style_value);
+		elm->SetAttribute(NS_LITERAL_STRING("style"), style_value);
 		g_free(v);
 	}
 	
@@ -1631,10 +1622,8 @@ KzMozWrapper::GetLinksFromWindow (nsIDOMWindow *domWindow,
 		nsCOMPtr<nsIDOMDocument> domDoc;
 		domWindow->GetDocument(getter_AddRefs(domDoc));
 
-		nsAutoString tagname;
-		tagname.AssignWithConversion("a");
 		nsCOMPtr<nsIDOMNodeList> nodeList;
-		rv = domDoc->GetElementsByTagName(tagname,
+		rv = domDoc->GetElementsByTagName(NS_LITERAL_STRING("a"),
 						  getter_AddRefs(nodeList));
 	        if (NS_FAILED(rv) || !nodeList) return NS_ERROR_FAILURE;
 
@@ -1675,7 +1664,7 @@ KzMozWrapper::GetLinksFromWindow (nsIDOMWindow *domWindow,
 }
 
 nsresult 
-KzMozWrapper::GetAttributeFromNode (nsIDOMNode *node, char *name, char **value)
+KzMozWrapper::GetAttributeFromNode (nsIDOMNode *node, const nsAString& attr, char **value)
 {
      	nsresult result;
 
@@ -1683,10 +1672,6 @@ KzMozWrapper::GetAttributeFromNode (nsIDOMNode *node, char *name, char **value)
 	result = node->GetAttributes(getter_AddRefs(attributes));
 	if (!NS_SUCCEEDED (result) || !attributes) return NS_ERROR_FAILURE;
 
-	nsAutoString attr; 
-
-	attr.AssignWithConversion(name);
-
 	nsCOMPtr<nsIDOMNode> attrNode;
 	result = attributes->GetNamedItem (attr, getter_AddRefs(attrNode));
 	if (!NS_SUCCEEDED(result) || !attrNode)  return NS_ERROR_FAILURE;
@@ -1708,7 +1693,7 @@ KzMozWrapper::GetLinkFromNode (nsIDOMDocument *domDoc, nsIDOMNode *node,
 
 	// get url
 	char *hrefattr =  NULL;
-	GetAttributeFromNode(node, "href", &hrefattr);
+	GetAttributeFromNode(node, NS_LITERAL_STRING("href"), &hrefattr);
 	if (!hrefattr) return NS_ERROR_FAILURE;	
 
 	nsAutoString hrefa;
@@ -1756,9 +1741,7 @@ KzMozWrapper::GetLinkAndTitleFromNode (nsIDOMDocument *domDoc, nsIDOMNode *node,
 	node->GetAttributes(getter_AddRefs(attributes));
 
 	nsCOMPtr<nsIDOMNode> hrefNode;
-	nsAutoString href; 
-	href.AssignWithConversion("href");
-	attributes->GetNamedItem(href, getter_AddRefs(hrefNode));
+	attributes->GetNamedItem(NS_LITERAL_STRING("href"), getter_AddRefs(hrefNode));
 	if (!hrefNode) return NS_ERROR_FAILURE;
 
 	nsAutoString linkhtml;
