@@ -19,10 +19,10 @@
  */
 
 #include "prefs_privacy.h"
+#include <glib/gi18n.h>
 
 #include "mozilla-prefs.h"
 #include "kazehakase.h"
-#include "utils/intl.h"
 #include "kz-window.h"
 
 #define DATA_KEY "KzPrefsPrivacy::info"
