@@ -17,14 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-downloader-sidebar.c,v 1.6 2004/09/12 08:22:56 ikezoe Exp $
+ *  $Id: kz-downloader-sidebar.c,v 1.7 2004/09/30 00:06:07 ikezoe Exp $
  */
 
 #include "kz-downloader-sidebar.h"
 
+#include <glib/gi18n.h>
 #include "kazehakase.h"
 #include "gobject-utils.h"
-#include "intl.h"
 #include "kz-cellrendererprogress.h"
 
 
