@@ -25,7 +25,7 @@
 
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
+#include <glib/gi18n.h>
 
 
 #define INNER_BORDER    2 
